@@ -251,6 +251,9 @@ class SoftwarePropertiesGtk(SoftwareProperties, SimpleGtkbuilderApp):
         # Show what we have early
         self.window_main.show()
 
+        # Did detect_drivers already run normally?
+        self.successfully_detected_drivers = False
+
         # used to store the handlers of callbacks
         self.handlers = {}
 
@@ -315,7 +318,8 @@ class SoftwarePropertiesGtk(SoftwareProperties, SimpleGtkbuilderApp):
             self.button_revert.set_visible(True)
 
     def maybe_detect_drivers(self):
-        if not self.search_process or not self.search_process.is_alive():
+        is_detecting_drivers = self.search_process and self.search_process.is_alive()
+        if not (self.successfully_detected_drivers or is_detecting_drivers):
             t = threading.Thread(target=self.detect_drivers)
             self.label_driver_detail.set_text(_("Searching for available drivers..."))
             t.start()
@@ -1431,6 +1435,7 @@ class SoftwarePropertiesGtk(SoftwareProperties, SimpleGtkbuilderApp):
 
     def on_detect_drivers_done(self, err=None):
         if err is None:
+            self.successfully_detected_drivers = True
             self.button_drivers_control.set_sensitive(False)
             self.show_drivers()
             return
